@@ -26,7 +26,7 @@ This module is very ugly and is intended to be rewritten sometimes.
 """
 
 __author__  = "Milan Zamazal <pdm@freesoft.cz>"
-__version__ = "$Id: cgiscript.py,v 1.18 1999/08/02 22:33:26 pdm Exp $"
+__version__ = "$Id: cgiscript.py,v 1.20 2000/01/09 19:38:27 pdm Exp $"
 __copyright__ = "GNU General Public License, version 2"
 
 
@@ -504,7 +504,18 @@ def edit (form):
             rstate = remove_crs (v)
         elif k in ('class', 'severity', 'priority', 'category', 'release',
                    'responsible', 'state', 'synopsis'):
-            new_items[k] = string.strip (v)
+            v = string.strip (v)
+            new_items[k] = v
+            if k == 'category' and \
+               (not form.has_key ('responsible')
+                or form['responsible'] == items['responsible']):
+                cats = G.categories_full ()
+                for c in cats:
+                    if c[0] == v:
+                        r = c[3]
+                        if r != items['responsible']:
+                            new_items['responsible'] = r
+                        break
         elif k in ('description', 'how-to-repeat', 'fix',
                    'environment'):
             new_items[k] = remove_crs (v)
@@ -548,7 +559,8 @@ def edit (form):
     changes = map (lambda k: k+'\n', new_items.keys ())
     changes = string.join (changes, '')
     big_changes = remail = ''
-    if new_items.has_key ('responsible') and rresponsible:
+    if new_items.has_key ('responsible') and \
+       new_items['responsible'] != items['responsible']:
         big_changes = big_changes + \
                       L('Responsible changed to %s.\nReason:\n%s\n\n') % \
                       (new_items['responsible'], rresponsible)
